@@ -16,29 +16,27 @@ from invenio_cli.helpers.docker_helper import DockerHelper
 
 
 @pytest.mark.skip()
-@patch('invenio_cli.helpers.docker_helper.run_cmd')
+@patch("invenio_cli.helpers.docker_helper.run_cmd")
 def test_start_containers(p_run_cmd):
     # Needed to fake call to docker-compose --version but not call
     # to docker-compose up
     def fake_normalize_name(self, project_shortname):
-        return 'project_shortname'
+        return "project_shortname"
 
-    with patch.object(DockerHelper, '_normalize_name', fake_normalize_name):
-        docker_helper = DockerHelper('project-shortname', local=True)
+    with patch.object(DockerHelper, "_normalize_name", fake_normalize_name):
+        docker_helper = DockerHelper("project-shortname", local=True)
 
     docker_helper.start_containers()
 
     p_run_cmd.run.assert_called_with(
-        ['docker-compose', '--file', 'docker-compose.yml', 'up',
-         '--build', '-d']
+        ["docker-compose", "--file", "docker-compose.yml", "up", "--build", "-d"]
     )
 
-    with patch.object(DockerHelper, '_normalize_name', fake_normalize_name):
-        docker_helper = DockerHelper('project-shortname', local=False)
+    with patch.object(DockerHelper, "_normalize_name", fake_normalize_name):
+        docker_helper = DockerHelper("project-shortname", local=False)
 
     docker_helper.start_containers()
 
     p_run_cmd.run.assert_called_with(
-        ['docker-compose', '--file', 'docker-compose.full.yml', 'up',
-         '--build', '-d']
+        ["docker-compose", "--file", "docker-compose.full.yml", "up", "--build", "-d"]
     )
